aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/pet_control/pet_control.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/titanic/pet_control/pet_control.h')
-rw-r--r--engines/titanic/pet_control/pet_control.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/engines/titanic/pet_control/pet_control.h b/engines/titanic/pet_control/pet_control.h
index 758069e5f1..652a6e8c83 100644
--- a/engines/titanic/pet_control/pet_control.h
+++ b/engines/titanic/pet_control/pet_control.h
@@ -307,9 +307,10 @@ public:
CString getFullViewName();
/**
* Adds a room to the room list
*/
- void addRoom(int roomNum);
+ void addRandomRoom(int passClassNum);
+
int roomFn2(int val);
/**
@@ -307,9 +307,10 @@ public:
CString getFullViewName();
/**
- * Adds a room to the room list
+ * Adds a random room to the room list
*/